#![allow(unused)]
use bevy::prelude::*;
use bevy_rapier2d::prelude::*;
use game::game_plugin;
use parallax::parallax_plugin;

mod game;
mod parallax;

const METER: f32 = 100.;

#[derive(States, Debug, Clone, PartialEq, Eq, Hash, Default)]
enum AppState {
    #[default]
    MainMenu,
    InGame,
    GameOver,
}

#[derive(States, Debug, Clone, PartialEq, Eq, Hash, Default)]
enum PausedState {
    Paused,
    #[default]
    Running,
}

fn main() {
    let rapier_config = RapierConfiguration {
        scaled_shape_subdivision: 2,
        timestep_mode: TimestepMode::Variable {
            max_dt: 0.2,
            time_scale: 1.0,
            substeps: 10,
        },
        gravity: Vec2::new(0.0, -9.81 * METER),
        physics_pipeline_active: true,
        query_pipeline_active: true,
        force_update_from_transform_changes: false,
    };
    App::new()
        .add_plugins(DefaultPlugins)
        .add_plugins(RapierPhysicsPlugin::<NoUserData>::pixels_per_meter(METER))
        .add_plugins(RapierDebugRenderPlugin::default())
        .add_systems(Startup, setup_camera)
        .add_plugins(game_plugin)
        .add_plugins(parallax_plugin)
        .init_state::<AppState>()
        .init_state::<PausedState>()
        .insert_state(AppState::InGame) // TODO dont
        .insert_resource(rapier_config)
        .run();
}

fn setup_camera(mut commands: Commands) {
    commands.spawn(Camera2dBundle::default());
}
